@@ -1,13 +1,17 @@
 import numpy as np
 
 from ama_xiv_combat_sim.simulator.damage_simulator import DamageSimulator
-from ama_xiv_combat_sim.simulator.skills.create_skill_library import create_skill_library
+from ama_xiv_combat_sim.simulator.skills.create_skill_library import (
+    create_skill_library,
+)
 from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.stats import Stats
 from ama_xiv_combat_sim.simulator.testing.test_class import TestClass
 from ama_xiv_combat_sim.simulator.timeline_builders.damage_builder import DamageBuilder
-from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import RotationBuilder
+from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import (
+    RotationBuilder,
+)
 from ama_xiv_combat_sim.simulator.utils import Utils
 
 
@@ -722,18 +726,69 @@ class TestJobs(TestClass):
         expected = (
             ("Hyosho Ranryu", 68433.6),
             ("Hyosho Ranryu", 52765.4),
-            ("_Bunshin_melee", 5954.4),
+            ("Gust Slash (pet)", 5954.4),
             ("Gust Slash", 6473.0),
-            ("_Bunshin_melee", 5968.4),
+            ("Aeolian Edge (pet)", 5968.4),
             ("Aeolian Edge", 8111.4),
-            ("_Bunshin_area", 2984.0),
+            ("Hakke Mujinsatsu (pet)", 2984.0),
             ("Hakke Mujinsatsu", 4054.4),
-            ("_Bunshin_melee", 5970.8),
+            ("Armor Crush (pet)", 5970.8),
             ("Armor Crush", 8093.4),
         )
 
         return self.__test_rotation_damage(rb, expected)
 
+    @TestClass.is_a_test
+    def test_nin_hyosho_regression(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.56,
+            main_stat=3360,
+            dh_stat=1582,
+            crit_stat=2554,
+            # det_stat=1679,
+            det_stat=1679,
+            speed_stat=400,
+            job_class="NIN",
+            version="6.55",
+        )
+
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            enable_autos=False,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )
+        rb.add(0, "Trick Attack")
+        rb.add(1, "Kassatsu")        
+        rb.add(3, "Hyosho Ranryu")
+            
+        rb.add(423.369, "Spinning Edge") ##
+        rb.add(425.947, "Kassatsu")
+        
+        rb.add(427.369, "Gust Slash")
+        rb.add(429.506, "Armor Crush")
+        rb.add(430.131, "Trick Attack")
+        rb.add(430.798, "Bhavacakra")
+        rb.add(431.642, "Ten")
+        rb.add(432.132, "Jin")
+        rb.add(432.622, "Hyosho Ranryu")
+        
+        expected = (
+            ("Trick Attack", 16168.67),
+            ("Hyosho Ranryu", 75249.11),
+            ("Spinning Edge", 8899.283),
+            ("Gust Slash", 12928.293),
+            ("Armor Crush", 17014.7),
+            ("Trick Attack", 16176.34),
+            ("Bhavacakra", 15577.1),
+            ("Hyosho Ranryu", 75066.2),
+            
+        )
+
+        return self.__test_rotation_damage(rb, expected)
+
     @TestClass.is_a_test
     def test_nin_aggregate_rotation(self):
         stats = Stats(
@@ -1833,9 +1888,9 @@ class TestJobs(TestClass):
         rb.add(215, "Stellar Detonation", skill_modifier=SkillModifier())
 
         expected = (
-            ("Stellar Detonation", 14899.6),
-            ("Stellar Detonation", 9840.6),
-            ("Stellar Detonation", 14899.6),
+            ("Stellar Explosion (pet)", 14899.6),
+            ("Stellar Explosion (pet)", 9840.6),
+            ("Stellar Explosion (pet)", 14899.6),
         )
 
         return self.__test_rotation_damage(rb, expected)
