@@ -8,8 +8,6 @@ from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.job_resource_settings import JobResourceSettings
-from ama_xiv_combat_sim.simulator.specs.job_resource_spec import JobResourceSpec
 from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
@@ -124,7 +122,6 @@ def add_mnk_skills(skill_library):
                     "Rockbreaker",
                     "Four-point Fury",
                     "Elixir Burst",
-                    "Leaping Opo",
                     "Fire's Reply",
                 ),
             ),
@@ -251,10 +248,7 @@ def add_mnk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1290, gcd_base_recast_time=2000
             ),
-            follow_up_skills={SimConsts.DEFAULT_CONDITION: tuple(),
-                              'Opo-opo Form': (opo_opo_fury_follow_up,),
-                              'Formless Fist': (opo_opo_fury_follow_up,),
-                              'Opo-opo Form, Formless Fist': (opo_opo_fury_follow_up,)}
+            follow_up_skills=(opo_opo_fury_follow_up,),
         )
     )
     skill_library.add_skill(
@@ -451,7 +445,6 @@ def add_mnk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=760, gcd_base_recast_time=2000
             ),
-            follow_up_skills = (opo_opo_form_follow_up,)
         )
     )
     skill_library.add_skill(
@@ -492,7 +485,6 @@ def add_mnk_skills(skill_library):
             name="Perfect Balance",
             is_GCD=False,
             timing_spec=instant_timing_spec,  # Does apply instantly it seems.
-            #fix this- PB charges can be eaten by non-opo skills too.
             follow_up_skills=(
                 opo_opo_form_follow_up,
                 opo_opo_form_follow_up,
