@@ -246,6 +246,38 @@ class TestJobs(TestClass):
         )
         return self.__test_skills(stats, skills_and_expected_damage)
 
+    @TestClass.is_a_test
+    def test_ast_star(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=3.2,
+            main_stat=3366,
+            det_stat=2047,
+            crit_stat=2430,
+            dh_stat=400,
+            speed_stat=1350,
+            job_class="AST",
+            healer_or_caster_strength=214,
+            version="6.55",
+        )
+
+        rb = RotationBuilder(stats, self.__skill_library)
+        rb.add(0, "Earthly Star", skill_modifier=SkillModifier())
+
+        rb.add(100, "Earthly Star", skill_modifier=SkillModifier())
+        rb.add(108, "Stellar Detonation", skill_modifier=SkillModifier())
+
+        rb.add(200, "Earthly Star", skill_modifier=SkillModifier())
+        rb.add(215, "Stellar Detonation", skill_modifier=SkillModifier())
+
+        expected = (
+            ("Stellar Explosion (pet)", 14899.6),
+            ("Stellar Explosion (pet)", 9840.6),
+            ("Stellar Explosion (pet)", 14899.6),
+        )
+
+        return self.__test_rotation_damage(rb, expected)
+
     @TestClass.is_a_test
     def test_war_skills(self):
         stats = Stats(
@@ -520,7 +552,52 @@ class TestJobs(TestClass):
             ("Disesteem", SkillModifier(), 20705.0),
         )
         return self.__test_skills(stats, skills_and_expected_damage)
+    
+    @TestClass.is_a_test
+    def test_drk_aggregate_rotation(self):
+        stats = Stats(
+            wd=126,
+            weapon_delay=2.96,
+            main_stat=2906,
+            det_stat=1883,
+            crit_stat=2352,
+            dh_stat=868,
+            speed_stat=650,
+            tenacity=631,
+            job_class="DRK",
+            version="6.55",
+        )
+        rb = RotationBuilder(stats, self.__skill_library, enable_autos=True)
 
+        rb.add_next("Hard Slash")
+        rb.add_next("Edge of Shadow")
+        rb.add_next("Syphon Strike")
+        rb.add_next("Grade 8 Tincture")
+        rb.add_next("Souleater")
+        rb.add_next("Living Shadow")
+        rb.add_next("Salted Earth")
+        rb.add_next("Bloodspiller")
+        rb.add_next("Shadowbringer")
+        rb.add_next("Edge of Shadow")
+        rb.add_next("Bloodspiller")
+        rb.add_next("Carve and Spit")
+        rb.add_next("Bloodspiller")
+        rb.add_next("Edge of Shadow")
+        rb.add_next("Salt and Darkness")
+        rb.add_next("Hard Slash")
+        rb.add_next("Edge of Shadow")
+        rb.add_next("Syphon Strike")
+        rb.add_next("Shadowbringer")
+        rb.add_next("Edge of Shadow")
+        rb.add_next("Souleater")
+        rb.add_next("Hard Slash")
+        rb.add_next("Syphon Strike")
+        rb.add_next("Souleater")
+        expected_damage = 409849.1
+        expected_total_time = 26993.0
+
+        return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
+    
     @TestClass.is_a_test
     def test_dnc_skills(self):
         stats = Stats(
@@ -1009,6 +1086,53 @@ class TestJobs(TestClass):
         )
         return self.__test_rotation_damage(rb, expected)
 
+    @TestClass.is_a_test
+    def test_nin_hyosho_regression(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.56,
+            main_stat=3360,
+            dh_stat=1582,
+            crit_stat=2554,
+            # det_stat=1679,
+            det_stat=1679,
+            speed_stat=400,
+            job_class="NIN",
+            version="7.0",
+        )
+
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            enable_autos=False,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )        
+        rb.add(1, "Kassatsu")        
+        rb.add(3, "Hyosho Ranryu")
+            
+        rb.add(423.369, "Spinning Edge") ##
+        rb.add(425.947, "Kassatsu")
+        
+        rb.add(427.369, "Gust Slash")
+        rb.add(429.506, "Armor Crush")
+        rb.add(430.798, "Bhavacakra")
+        rb.add(431.642, "Ten")
+        rb.add(432.132, "Jin")
+        rb.add(432.622, "Hyosho Ranryu")
+        
+        expected = (
+            ("Hyosho Ranryu", 68225.1),
+            ("Spinning Edge", 11334.9),
+            ("Gust Slash", 14550.4),
+            ("Armor Crush", 18577.1),
+            ("Bhavacakra", 15372.9),
+            ("Hyosho Ranryu", 68306.8),
+            
+        )
+
+        return self.__test_rotation_damage(rb, expected)
+
     @TestClass.is_a_test
     def test_nin_damage_instances(self):
         stats = Stats(
@@ -1130,13 +1254,13 @@ class TestJobs(TestClass):
         expected = (
             ("Hyosho Ranryu", 68433.6),
             ("Hyosho Ranryu", 52765.4),
-            ("_Bunshin_melee", 5984.8),
+            ("Gust Slash (pet)", 5984.8),
             ("Gust Slash", 8115.2),
-            ("_Bunshin_melee", 5968.4),
+            ("Aeolian Edge (pet)", 5968.4),
             ("Aeolian Edge", 9723.2),
-            ("_Bunshin_area", 2984.0),
+            ("Hakke Mujinsatsu (pet)", 2984.0),
             ("Hakke Mujinsatsu", 4054.4),
-            ("_Bunshin_melee", 5970.8),
+            ("Armor Crush (pet)", 5970.8),
             ("Armor Crush", 9727.0),
         )
 
@@ -1650,7 +1774,7 @@ class TestJobs(TestClass):
         rb.add_next("Blizzard IV")
         rb.add_next("Thunder III")
 
-        expected_damage = 442172.1
+        expected_damage = 444172.1
         expected_total_time = 24660.0
         return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
 
